%define        pkgver %(echo %version | sed "s|[a-z]||")
Name:          texinfo
Version:       7.0
Release:       1mamba
Summary:       Tools needed to create Texinfo format documentation files
Group:         Applications/Publishing
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://www.gnu.org/software/texinfo/
Source:        https://ftp.gnu.org/gnu/texinfo/texinfo-%{version}.tar.xz
License:       GPL
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libncurses-devel
BuildRequires: libperl
BuildRequires: perl-Text-Unidecode
BuildRequires: perl-Unicode-EastAsianWidth
BuildRequires: perl-devel
BuildRequires: perl-libintl
## AUTOBUILDREQ-END
BuildRequires: gettext-devel
Provides:      perl(Texinfo::Parser)
Provides:      perl(Texinfo::ParserNonXS)
Requires:      gzip >= 1.2.4a
Requires(post): %{__install_info}

# checking for hevea... no
#   http://hevea.inria.fr/index.html

%description
Texinfo is a documentation system that can produce both online information and printed output from a single source file.
Normally, you'd have to write two separate documents: one for online help or other online information and the other for a typeset manual or other printed work.
Using Texinfo, you only need to write one source document.
Then when the work needs revision, you only have to revise one source document.
The GNU Project uses the Texinfo file format for most of its documentation.

Install texinfo if you want a documentation system for producing both online and print documentation from the same source file and/or if you are going to write documentation for the GNU Project.

%debug_package

%prep
%setup -q -n %{name}-%{pkgver}

%build
%configure \
   --with-external-libintl-perl \
   --with-external-Unicode-EastAsianWidth \
   --with-external-Text-Unidecode

%if "%{_host}" != "%{_build}"
%make -C tools/gnulib/lib
%endif

%make

%if "%{_build}" == "%{_host}"
make check || :
%endif

%install
[ "%{buildroot}" != / ] && rm -rf %{buildroot}
%makeinstall
#install -m755 util/gen-dir-node %{buildroot}%{_bindir}/gen-dir-node

install -d %{buildroot}/sbin
mv -f %{buildroot}%{_bindir}/install-info %{buildroot}/sbin

# these files are already in the TeTeX package
#make TEXMF=%{buildroot}%{_datadir}/texmf install-tex
#rm -f %{buildroot}%{_bindir}/texi2pdf

%find_lang %{name}
%find_lang %{name}_document

cat %{name}_document.lang >> %{name}.lang

%clean
[ "%{buildroot}" != / ] && rm -rf %{buildroot}

%post
%install_info info-stnd.info
%install_info texi2any_api.info
%install_info texi2any_internals.info
:

%preun
%uninstall_info info-stnd.info
%uninstall_info texi2any_api.info
%uninstall_info texi2any_internals.info
:

%files -f %{name}.lang
%defattr(-,root,root)
/sbin/install-info
%{_bindir}/info
#%{_bindir}/infokey
%{_bindir}/makeinfo
%{_bindir}/pod2texi
%{_bindir}/texi2any
%{_bindir}/texi2dvi
%{_bindir}/texi2pdf
%{_bindir}/texindex
%{_bindir}/pdftexi2dvi
%dir %{_libdir}/texinfo
%{_libdir}/texinfo/MiscXS.*
%{_libdir}/texinfo/Parsetexi.*
%{_libdir}/texinfo/XSParagraph.*
%dir %{_datadir}/texinfo
%{_datadir}/texinfo/*
%{_infodir}/texinfo*
#%{_infodir}/info.info*
%{_infodir}/info-stnd.info*
%{_infodir}/texi2any_api.info*
%{_infodir}/texi2any_internals.info*
%{_mandir}/man1/info.*
#%{_mandir}/man1/infokey.*
%{_mandir}/man1/install-info.*
%{_mandir}/man1/makeinfo.*
%{_mandir}/man1/pdftexi2dvi.*
%{_mandir}/man1/pod2texi.1*
%{_mandir}/man1/texi2any.1*
%{_mandir}/man1/texi2dvi.*
%{_mandir}/man1/texi2pdf.*
%{_mandir}/man1/texindex.*
%{_mandir}/man5/info.*
%{_mandir}/man5/texinfo.*
%doc AUTHORS COPYING
#ChangeLog INTRODUCTION NEWS README TODO

%changelog
* Wed Nov 16 2022 Silvan Calarco <silvan.calarco@mambasoft.it> 7.0-1mamba
- update to 7.0

* Sat Jul 03 2021 Automatic Build System <autodist@mambasoft.it> 6.8-1mamba
- automatic version update by autodist

* Sun Apr 26 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 6.7-2mamba
- provide perl(Texinfo::ParseNonXS) to fix auto requirement

* Sun Sep 29 2019 Automatic Build System <autodist@mambasoft.it> 6.7-1mamba
- automatic version update by autodist

* Mon Jul 15 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 6.6-2mamba
- manually provide perl(Texinfo::Parser) to resolve self-deps

* Wed Mar 06 2019 Automatic Build System <autodist@mambasoft.it> 6.6-1mamba
- automatic version update by autodist

* Tue Oct 24 2017 Automatic Build System <autodist@mambasoft.it> 6.5-1mamba
- automatic version update by autodist

* Mon Aug 14 2017 Automatic Build System <autodist@mambasoft.it> 6.4-1mamba
- automatic version update by autodist

* Wed Dec 07 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 6.3-2mamba
- rebuilt with perl 5.24

* Sun Sep 11 2016 Automatic Build System <autodist@mambasoft.it> 6.3-1mamba
- automatic version update by autodist

* Sun Feb 14 2016 Automatic Build System <autodist@mambasoft.it> 6.1-1mamba
- automatic version update by autodist

* Wed Jul 01 2015 Automatic Build System <autodist@mambasoft.it> 6.0-1mamba
- automatic update by autodist

* Fri Sep 27 2013 Automatic Build System <autodist@mambasoft.it> 5.2-1mamba
- automatic version update by autodist

* Sun Mar 17 2013 Automatic Build System <autodist@mambasoft.it> 5.1-1mamba
- automatic version update by autodist

* Fri Feb 22 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 5.0-2mamba
- rebuilt using system perl requirements

* Mon Feb 18 2013 Automatic Build System <autodist@mambasoft.it> 5.0-1mamba
- update to 5.0

* Thu Sep 25 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 4.13a-1mamba
- automatic update to 4.13a by autodist

* Sat Sep 20 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 4.13-1mamba
- automatic update to 4.13 by autodist

* Wed Apr 30 2008 Aleph0 <aleph0@openmamba.org> 4.12-1mamba
- update to 4.12

* Thu Sep 20 2007 Aleph0 <aleph0@openmamba.org> 4.11-1mamba
- update to 4.11
- removed fix against CAN-2005-3011: incorporated upstream
- removed previous patch: fixed upstream

* Tue Jul 24 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 4.9-2mamba
- texi2dvi: added a patch to fix the move_to_dest function

* Mon Jul 02 2007 Aleph0 <aleph0@openmamba.org> 4.9-1mamba
- update to 4.9

* Thu May 17 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 4.8-10mamba
- restore texi2pdf

* Mon Oct 10 2005 Davide Madrisan <davide.madrisan@qilinux.it> 4.8-9qilnx
- security fix QSA-2005-115 (CAN-2005-3011)

* Wed Sep 21 2005 Davide Madrisan <davide.madrisan@qilinux.it> 4.8-8qilnx
- specfile fixes

* Wed Sep 21 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 4.8-7qilnx
- reverted back to using scripts,changed bootstrap installation way
- multiplatform build

* Wed Sep 21 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 4.8-6qilnx
- remove scripts to avoid a PreReq dependency on bash

* Thu Apr 07 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 4.8-5qilnx
- removed execution of gen-dir-node and its PreReqs

* Mon Mar 14 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 4.8-4qilnx
- added prereq for sed

* Fri Mar 11 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 4.8-3qilnx
- added PreReq's

* Wed Jan 05 2005 Davide Madrisan <davide.madrisan@qilinux.it> 4.8-2qilnx
- added %%post and %%preun scripts

* Wed Jan 05 2005 Davide Madrisan <davide.madrisan@qilinux.it> 4.8-1qilnx
- update to version 4.8 by autospec
- fixed package group

* Tue Apr 13 2004 Davide Madrisan <davide.madrisan@qilinux.it> 4.7-1qilnx
- new version rebuild

* Wed Mar 03 2004 Davide Madrisan <davide.madrisan@qilinux.it> 4.6-1qilnx
- specfile cleanups
- rebuilt with texinfo-4.6
